==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/gpssync/kipiplugin_gpssync.desktop.cmake <==
[Desktop Entry]
Comment=A tool to geolocalize pictures
Comment[ast]=Una ferramienta pa llocalizar xeográficamente imáxenes
Comment[bg]=Инструмент за геолокация на снимки
Comment[ca]=Una eina per a geolocalitzar fotografies
Comment[ca@valencia]=Una eina per a geolocalitzar fotografies
Comment[cs]=Nástroj pro geolokaci obrázků
Comment[da]=Et værktøj til at lokalisere billeder geografisk
Comment[de]=Ein Werkzeug, um Bilder geografisch zuzuordnen.
Comment[el]=Ένα εργαλείο γεωτοποθέτησης εικόνων
Comment[en_GB]=A tool to geolocalise pictures
Comment[es]=Herramienta para geolocalizar las imágenes
Comment[et]=Tööriist piltide geolokatsiooniks
Comment[eu]=Irudiak geolokalizatzeko tresna
Comment[fi]=Maantieteellinen paikannus
Comment[fr]=Outil pour la géolocalisation d'images
Comment[gl]=Unha ferramenta para localizar imaxes xeograficamente
Comment[he]=כלי למיקום גיאוגרפי של תמונות
Comment[hne]=फोटू ल जियोलोकलाइज करे के एक औजार
Comment[hu]=Egy eszköz képek helyének meghatározásához
Comment[is]=Verkfæri til að hnattstaðsetja myndir
Comment[it]=Uno strumento per geolocalizzare le immagini
Comment[ja]=ジオロケーション (地理位置情報) を扱うツール
Comment[km]=ឧបករណ៍​ដើម្បី​ធ្វើ​មូលដ្ឋានីយកម្ម​​រូបភាព​នឹង​កន្លែង
Comment[lv]=Rīks attēlu uzņemšanas vietas fiksēšanai
Comment[nb]=Et verktøy for geografisk plassering av bilder
Comment[nds]=En Warktüüch, dat Biller Steden towiest
Comment[nl]=Een hulpmiddel om afbeeldingen te voorzien van een geografische locatie
Comment[pa]=ਗਲੋਬਲਾਈਜ਼ ਤਸਵੀਰਾਂ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do geolokalizacji zdjęć
Comment[pt]=Uma ferramenta de geo-localização das imagens
Comment[pt_BR]=Uma ferramenta para localização geográfica das imagens
Comment[ro]=O unealtă pentru geolocalizarea imaginilor
Comment[ru]=Инструмент для определения мест съёмок изображений
Comment[sk]=Nástroj na geolokalizáciu obrázkov
Comment[sl]=Orodje za geo-lokalizacijo slik
Comment[sq]=Një mjet për të gjeolokalizuar fotografitë
Comment[sv]=Ett verktyg för att lokalisera bilder geografiskt
Comment[th]=เครื่องมือกำหนดค่าพิกัดเชิงภูมิศาสตร์ให้กับภาพ
Comment[tr]=Resimlerin coğrafi konumunu belirtme eklentisi
Comment[uk]=Інструмент для геопозиціювання зображень
Comment[x-test]=xxA tool to geolocalize picturesxx
Comment[zh_CN]=一个图片地理化工具
Comment[zh_TW]=圖片地理定位的工具
Icon=applications-internet
Name=GPSSync
Name[ast]=GPSSync
Name[bg]=Синхронизиране по GPS
Name[ca]=GPSSync
Name[ca@valencia]=GPSSync
Name[cs]=GPSSync
Name[da]=GPSSync
Name[de]=GPSSync
Name[el]=Συγχρονισμός GPS
Name[en_GB]=GPSSync
Name[es]=GPSSync
Name[et]=GPSSync
Name[eu]=GPSSync
Name[fi]=GPS-synkronointi
Name[fr]=GPSSync
Name[ga]=GPSSync
Name[gl]=GPSSync
Name[he]=סנכרון GPS
Name[hne]=जीपीएससिंक
Name[hu]=GPSSync
Name[is]=GPSSync
Name[it]=GPSSync
Name[ja]=GPSSync
Name[km]=GPSSync
Name[lv]=GPSSync
Name[nb]=GPSSync
Name[nds]=GPSSync
Name[nl]=GPSSync
Name[pa]=GPSSync
Name[pl]=GPSSync
Name[pt]=GPSSync
Name[pt_BR]=Sincronização de GPS
Name[ro]=GPSSync
Name[ru]=Синхронизация с GPS
Name[sk]=GPSSync
Name[sl]=GPSSync
Name[sq]=GPSSync
Name[sv]=GPS-synkronisering
Name[th]=กำหนดค่าพิกัดเชิงภูมิศาสตร์
Name[tr]=GPSSync
Name[uk]=GPSSync
Name[x-test]=xxGPSSyncxx
Name[zh_CN]=全球定位同步
Name[zh_TW]=GPS 同步
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_gpssync
X-KIPI-ReqFeatures=ImagesHasTime
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam-4.6.0.tar.bz2: digikam-4.6.0/extra/kipi-plugins/gpssync/kipiplugin_gpssync.desktop.cmake <==
[Desktop Entry]
Comment=A tool to geolocalize pictures
Comment[ast]=Una ferramienta pa llocalizar xeográficamente imáxenes
Comment[bg]=Инструмент за геолокация на снимки
Comment[bs]=Alat za geolokalizaciju slika
Comment[ca]=Una eina per a geolocalitzar fotografies
Comment[ca@valencia]=Una eina per a geolocalitzar fotografies
Comment[cs]=Nástroj pro geolokaci obrázků
Comment[da]=Et værktøj til at lokalisere billeder geografisk
Comment[de]=Ein Werkzeug, um Bilder geografisch zuzuordnen.
Comment[el]=Ένα εργαλείο γεωτοποθέτησης εικόνων
Comment[en_GB]=A tool to geolocalise pictures
Comment[es]=Herramienta para geolocalizar las imágenes
Comment[et]=Tööriist piltide geolokatsiooniks
Comment[eu]=Irudiak geolokalizatzeko tresna
Comment[fi]=Maantieteellinen paikannus
Comment[fr]=Outil pour la géolocalisation d'images
Comment[gl]=Unha ferramenta para localizar imaxes xeograficamente
Comment[he]=כלי למיקום גיאוגרפי של תמונות
Comment[hne]=फोटू ल जियोलोकलाइज करे के एक औजार
Comment[hu]=Egy eszköz képek helyének meghatározásához
Comment[is]=Verkfæri til að hnattstaðsetja myndir
Comment[it]=Uno strumento per geolocalizzare le immagini
Comment[ja]=ジオロケーション (地理位置情報) を扱うツール
Comment[km]=ឧបករណ៍​ដើម្បី​ធ្វើ​មូលដ្ឋានីយកម្ម​​រូបភាព​នឹង​កន្លែង
Comment[lv]=Rīks attēlu uzņemšanas vietas fiksēšanai
Comment[nb]=Et verktøy for geografisk plassering av bilder
Comment[nds]=En Warktüüch, dat Biller Steden towiest
Comment[nl]=Een hulpmiddel om afbeeldingen te voorzien van een geografische locatie
Comment[pa]=ਗਲੋਬਲਾਈਜ਼ ਤਸਵੀਰਾਂ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do geolokalizacji zdjęć
Comment[pt]=Uma ferramenta de geo-localização das imagens
Comment[pt_BR]=Ferramenta para localização geográfica das imagens
Comment[ro]=O unealtă pentru geolocalizarea imaginilor
Comment[ru]=Инструмент для определения мест съёмок изображений
Comment[sk]=Nástroj na geolokalizáciu obrázkov
Comment[sl]=Orodje za geo-lokalizacijo slik
Comment[sq]=Një mjet për të gjeolokalizuar fotografitë
Comment[sv]=Ett verktyg för att lokalisera bilder geografiskt
Comment[th]=เครื่องมือกำหนดค่าพิกัดเชิงภูมิศาสตร์ให้กับภาพ
Comment[tr]=Resimlerin coğrafi konumunu belirtme eklentisi
Comment[uk]=Інструмент для геопозиціювання зображень
Comment[x-test]=xxA tool to geolocalize picturesxx
Comment[zh_CN]=一个图片地理化工具
Comment[zh_TW]=圖片地理定位的工具
Icon=applications-internet
UntranslatedGenericName=GPSSync
Name=GPSSync
Name[ast]=GPSSync
Name[bg]=Синхронизиране по GPS
Name[bs]=GPSSync
Name[ca]=GPSSync
Name[ca@valencia]=GPSSync
Name[cs]=GPSSync
Name[da]=GPSSync
Name[de]=GPSSync
Name[el]=Συγχρονισμός GPS
Name[en_GB]=GPSSync
Name[es]=GPSSync
Name[et]=GPSSync
Name[eu]=GPSSync
Name[fi]=GPS-synkronointi
Name[fr]=GPSSync
Name[ga]=GPSSync
Name[gl]=GPSSync
Name[he]=סנכרון GPS
Name[hne]=जीपीएससिंक
Name[hu]=GPSSync
Name[is]=GPSSync
Name[it]=GPSSync
Name[ja]=GPSSync
Name[km]=GPSSync
Name[lv]=GPSSync
Name[nb]=GPSSync
Name[nds]=GPSSync
Name[nl]=GPSSync
Name[pa]=GPSSync
Name[pl]=GPSSync
Name[pt]=GPSSync
Name[pt_BR]=Sincronização de GPS
Name[ro]=GPSSync
Name[ru]=Синхронизация с GPS
Name[sk]=GPSSync
Name[sl]=GPSSync
Name[sq]=GPSSync
Name[sv]=GPS-synkronisering
Name[th]=กำหนดค่าพิกัดเชิงภูมิศาสตร์
Name[tr]=GPSSync
Name[uk]=GPSSync
Name[x-test]=xxGPSSyncxx
Name[zh_CN]=全球定位同步
Name[zh_TW]=GPS 同步
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_gpssync
X-KIPI-ReqFeatures=ImagesHasTime
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
